package goblincave.gitea.nes;

public class Logo {

	/**
	 * Creates an ASCII logo in RR6 style using the provided text.
	 * Supports alphanumeric text with spaces only.
	 * 
	 * @param text
	 * @return logo formatted text
	 */
	public static String format(String text) {
		return format(text, true, 10);
	}

	/**
	 * Creates an ASCII logo in RR6 style using the provided text.
	 * Supports alphanumeric text with spaces only.
	 * 
	 * @param string
	 * @param italicize logo
	 * @return logo formatted text
	 */
	public static String format(String string, boolean italic) {
		return format(string, italic, 10);
	}
	
	/**
	 * Creates an ASCII logo in RR6 style using the provided text.
	 * Supports alphanumeric text with spaces only.
	 * 
	 * @param text
	 * @param height 
	 * @param italicize logo
	 * @return logo formatted text
	 */
	public static String format(String text, boolean italic, int height) {
		
		// Initialize logo lines
		String[] logo = new String[10];
		for(int i = 0; i < logo.length; i++)
			logo[i] = new String();
		
		boolean spaced = false;
		for(int i = 0; i < text.length(); i++) {
			char c = text.charAt(i);

			// Add space from previous character
			if(i > 0) {
				if(c != ' ' && c!= ':' && !spaced) {
					for(int line = 0; line < logo.length - 1; line++)
						logo[line] += "   ";
					logo[9] += "███";
				}
				spaced = false;
			}
			
			// Add character to logo
			switch(c) {
				
				// Space
				case ':':
				case ' ':
					for(int line = 0; line < logo.length; line++)
						logo[line] += "    ";
					spaced = true;
					break;
					
				// Numbers
				case '0':
					if(logo[0].length() > 0)
						for(int x = 0; x < logo.length; x++)
							logo[x] = logo[x].substring(0, logo[x].length() - 1);
					logo[0] += " ██████████████████████    ";
					logo[1] += "████████████████████████   ";
					logo[2] += "████████        ████████   ";
					logo[3] += "████████        ████████   ";
					logo[4] += "████████        ████████   ";
					logo[5] += "████████        ████████   ";
					logo[6] += "████████        ████████   ";
					logo[7] += "████████        ████████   ";
					logo[8] += "████████████████████████   ";
					logo[9] += " ██████████████████████    ";
					spaced = true;
					break;	
				case '1':
					logo[0] += " ███████████████   ";
					logo[1] += "████████████████   ";
					logo[2] += "        ████████   ";
					logo[3] += "        ████████   ";
					logo[4] += "        ████████   ";
					logo[5] += "        ████████   ";
					logo[6] += "        ████████   ";
					logo[7] += "        ████████   ";
					logo[8] += "        ████████   ";
					logo[9] += "        ████████   ";
					spaced = true;
					break;
				case '2':
					logo[0] += " ███████████████████████   ";
					logo[1] += "████████████████████████   ";
					logo[2] += "████████        ████████   ";
					logo[3] += "                ████████   ";
					logo[4] += "  ██████████████████████   ";
					logo[5] += "████████████████████████   ";
					logo[6] += "████████                   ";
					logo[7] += "████████                   ";
					logo[8] += "████████████████████████   ";
					logo[9] += "███████████████████████    ";
					spaced = true;
					break;
				case '3':
					logo[0] += " ██████████████████████    ";
					logo[1] += "████████████████████████   ";
					logo[2] += "████████        ████████   ";
					logo[3] += "                ████████   ";
					logo[4] += "        ███████████████    ";
					logo[5] += "        ██████████████     ";
					logo[6] += "                ████████   ";
					logo[7] += "████████        ████████   ";
					logo[8] += "████████████████████████   ";
					logo[9] += " ██████████████████████    ";
					spaced = true;
					break;
				case '4':
					logo[0] += "         █████████████     ";
					logo[1] += "       ███████████████     ";
					logo[2] += "     ████       ██████     ";
					logo[3] += "   ██████       ██████     ";
					logo[4] += " ███████████████████████   ";
					logo[5] += "████████████████████████   ";
					logo[6] += "                ██████     ";
					logo[7] += "                ██████     ";
					logo[8] += "                ██████     ";
					logo[9] += "                ██████     ";
					spaced = true;
					break;
				case '5':
					logo[0] += " ███████████████████████   ";
					logo[1] += "████████████████████████   ";
					logo[2] += "████████                   ";
					logo[3] += "████████                   ";
					logo[4] += "████████████████████████   ";
					logo[5] += "████████████████████████   ";
					logo[6] += "                ████████   ";
					logo[7] += "                ████████   ";
					logo[8] += "████████████████████████   ";
					logo[9] += "███████████████████████    ";
					spaced = true;
					break;
				case '6':
					logo[0] += " ███████████████████████   ";
					logo[1] += "████████████████████████   ";
					logo[2] += "████████                   ";
					logo[3] += "████████                   ";
					logo[4] += "████████████████████████   ";
					logo[5] += "████████████████████████   ";
					logo[6] += "████████        ████████   ";
					logo[7] += "████████        ████████   ";
					logo[8] += "████████████████████████   ";
					logo[9] += "███████████████████████    ";
					spaced = true;
					break;
				case '7':
					logo[0] += " ███████████████████████   ";
					logo[1] += "████████████████████████   ";
					logo[2] += "████████        ████████   ";
					logo[3] += "                ████████   ";
					logo[4] += "                ████████   ";
					logo[5] += "                ████████   ";
					logo[6] += "                ████████   ";
					logo[7] += "                ████████   ";
					logo[8] += "                ████████   ";
					logo[9] += "                ████████   ";
					spaced = true;
					break;
				case '8':
					logo[0] += " ██████████████████████    ";
					logo[1] += "████████████████████████   ";
					logo[2] += "████████        ████████   ";
					logo[3] += "████████        ████████   ";
					logo[4] += "  █████████████████████    ";
					logo[5] += " █████████████████████     ";
					logo[6] += "████████        ████████   ";
					logo[7] += "████████        ████████   ";
					logo[8] += "████████████████████████   ";
					logo[9] += " ██████████████████████    ";
					spaced = true;
					break;
				case '9':
					logo[0] += " ██████████████████████   ";
					logo[1] += "████████████████████████   ";
					logo[2] += "████████        ████████   ";
					logo[3] += "████████        ████████   ";
					logo[4] += " ███████████████████████    ";
					logo[5] += "   █████████████████████     ";
					logo[6] += "                ████████   ";
					logo[7] += "                ████████   ";
					logo[8] += "                ████████   ";
					logo[9] += "                ████████    ";
					spaced = true;
					break;
				
				// Capital letters
				case 'A':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████████████";
					logo[7] += "████    ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'B':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "███████████ ";
					logo[6] += "████    ████";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'C':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "████        ";
					logo[4] += "████        ";
					logo[5] += "████        ";
					logo[6] += "████        ";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'D':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████    ████";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'E':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "████        ";
					logo[4] += "████        ";
					logo[5] += "████████████";
					logo[6] += "████        ";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'F':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "████        ";
					logo[4] += "████        ";
					logo[5] += "████████████";
					logo[6] += "████        ";
					logo[7] += "████        ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'G':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "████        ";
					logo[4] += "████        ";
					logo[5] += "████  ██████";
					logo[6] += "████    ████";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'H':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████    ████";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████████████";
					logo[6] += "████    ████";
					logo[7] += "████    ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'I':
					logo[0] += "    ";
					logo[1] += "    ";
					logo[2] += "████";
					logo[3] += "████";
					logo[4] += "████";
					logo[5] += "████";
					logo[6] += "████";
					logo[7] += "████";
					logo[8] += "    ";
					logo[9] += "████";
					break;
				case 'J':
					logo[0] += "        ";
					logo[1] += "        ";
					logo[2] += "  ██████";
					logo[3] += "    ████";
					logo[4] += "    ████";
					logo[5] += "    ████";
					logo[6] += "    ████";
					logo[7] += "████████";
					logo[8] += "        ";
					logo[9] += "████████";
					break;
				case 'K':
					logo[0] += "             ";
					logo[1] += "             ";
					logo[2] += "████    ████ ";
					logo[3] += "████   ████  ";
					logo[4] += "████  ████   ";
					logo[5] += "████ ████    ";
					logo[6] += "████████     ";
					logo[7] += "████  █████  ";
					logo[8] += "        █████";
					logo[9] += "███████   ███";
					spaced = true;
					break;
				case 'L':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████        ";
					logo[3] += "████        ";
					logo[4] += "████        ";
					logo[5] += "████        ";
					logo[6] += "████        ";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'M':
					logo[0] += "              ";
					logo[1] += "              ";
					logo[2] += "████      ████";
					logo[3] += "██████  ██████";
					logo[4] += "████ ████ ████";
					logo[5] += "████      ████";
					logo[6] += "████      ████";
					logo[7] += "████      ████";
					logo[8] += "              ";
					logo[9] += "██████████████";
					break;
				case 'N':
					logo[0] += "               ";
					logo[1] += "               ";
					logo[2] += "████    ████   ";
					logo[3] += "██████  ████   ";
					logo[4] += "███████ ████   ";
					logo[5] += "████ ███████   ";
					logo[6] += "████  ██████   ";
					logo[7] += "████    ████   ";
					logo[8] += "          ████ ";
					logo[9] += "█████████   ███";
					spaced = true;
					break;
				case 'O':
					if(logo[0].length() > 0)
						for(int x = 0; x < logo.length; x++)
							logo[x] = logo[x].substring(0, logo[x].length() - 1);
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += " ██████████ ";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████    ████";
					logo[7] += " ██████████ ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'P':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████████████";
					logo[7] += "████        ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'Q':
					logo[0] += "               ";
					logo[1] += "               ";
					logo[2] += " ███████████   ";
					logo[3] += "████    ████   ";
					logo[4] += "████    ████   ";
					logo[5] += "████    ████   ";
					logo[6] += "████    ████   ";
					logo[7] += "████████████   ";
					logo[8] += "          ████ ";
					logo[9] += "█████████   ███";
					spaced = true;
					break;
				case 'R':
					logo[0] += "               ";
					logo[1] += "               ";
					logo[2] += "████████████   ";
					logo[3] += "████    ████   ";
					logo[4] += "████    ████   ";
					logo[5] += "████    ████   ";
					logo[6] += "███████████    ";
					logo[7] += "█████   █████  ";
					logo[8] += "          █████";
					logo[9] += "█████████   ███";
					spaced = true;
					break;
				case 'S':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "████    ████";
					logo[4] += "  ████      ";
					logo[5] += "      ████  ";
					logo[6] += "████    ████";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'T':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "    ████    ";
					logo[4] += "    ████    ";
					logo[5] += "    ████    ";
					logo[6] += "    ████    ";
					logo[7] += "    ████    ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'U':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████    ████";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████    ████";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'V':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████    ████";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "  ████████  ";
					logo[7] += "    ████    ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'W':
					logo[0] += "              ";
					logo[1] += "              ";
					logo[2] += "████      ████";
					logo[3] += "████      ████";
					logo[4] += "████      ████";
					logo[5] += "████ ████ ████";
					logo[6] += "██████  ██████";
					logo[7] += "████      ████";
					logo[8] += "              ";
					logo[9] += "██████████████";
					break;
				case 'X':
					logo[0] += "               ";
					logo[1] += "               ";
					logo[2] += "████    ████   ";
					logo[3] += "████    ████   ";
					logo[4] += " ████  ████    ";
					logo[5] += "    ████       ";
					logo[6] += " ████  ████    ";
					logo[7] += "████    ████   ";
					logo[8] += "          █████";
					logo[9] += "█████████   ███";
					spaced = true;
					break;
				case 'Y':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████    ████";
					logo[3] += "████    ████";
					logo[4] += " ████  ████ ";
					logo[5] += "    ████    ";
					logo[6] += "    ████    ";
					logo[7] += "    ████    ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'Z':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "████████████";
					logo[3] += "        ████";
					logo[4] += "      ████  ";
					logo[5] += "  ████      ";
					logo[6] += "████        ";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
					
				// Lowercase letters
				case 'a':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += " ███████████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████████████";
					logo[7] += "████    ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'b':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████████████";
					logo[4] += "████    ████";
					logo[5] += "██████████  ";
					logo[6] += "████    ████";
					logo[7] += "███████████ ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'c':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += " ███████████";
					logo[4] += "████        ";
					logo[5] += "████        ";
					logo[6] += "████        ";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'd':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████████████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████    ████";
					logo[7] += "███████████ ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'e':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += " ███████████";
					logo[4] += "████        ";
					logo[5] += "████████████";
					logo[6] += "████        ";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'f':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += " ███████████";
					logo[4] += "████        ";
					logo[5] += "████████████";
					logo[6] += "████        ";
					logo[7] += "████        ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'g':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += " ███████████";
					logo[4] += "████        ";
					logo[5] += "████    ████";
					logo[6] += "████    ████";
					logo[7] += "███████████ ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'h':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████████████";
					logo[7] += "████    ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'i':
					logo[0] += "    ";
					logo[1] += "    ";
					logo[2] += "    ";
					logo[3] += "████";
					logo[4] += "████";
					logo[5] += "████";
					logo[6] += "████";
					logo[7] += "████";
					logo[8] += "    ";
					logo[9] += "████";
					break;
				case 'j':
					logo[0] += "        ";
					logo[1] += "        ";
					logo[2] += "        ";
					logo[3] += "  ██████";
					logo[4] += "    ████";
					logo[5] += "    ████";
					logo[6] += "    ████";
					logo[7] += "████████";
					logo[8] += "    ";
					logo[9] += "████████";
					break;
				case 'k':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████    ████";
					logo[4] += "████  ████  ";
					logo[5] += "████████    ";
					logo[6] += "████  ████  ";
					logo[7] += "████    ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'l':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████        ";
					logo[4] += "████        ";
					logo[5] += "████        ";
					logo[6] += "████        ";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'm':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████   █████";
					logo[4] += "█████ ██████";
					logo[5] += "████ ██ ████";
					logo[6] += "████    ████";
					logo[7] += "████    ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'n':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████    ████";
					logo[4] += "█████   ████";
					logo[5] += "████ ██ ████";
					logo[6] += "████   █████";
					logo[7] += "████    ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'o':
					if(logo[0].length() > 0)
						for(int x = 0; x < logo.length; x++)
							logo[x] = logo[x].substring(0, logo[x].length() - 1);
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += " ██████████ ";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████    ████";
					logo[7] += " ██████████ ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'p':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████████████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "██████████  ";
					logo[7] += "████        ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'q':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += " ███████████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "  ██████████";
					logo[7] += "        ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'r':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████████████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "██████████  ";
					logo[7] += "████    ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 's':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████████████";
					logo[4] += "████        ";
					logo[5] += "    ████    ";
					logo[6] += "        ████";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 't':
					if(logo[0].length() > 0)
						for(int x = 0; x < logo.length; x++)
							logo[x] = logo[x].substring(0, logo[x].length() - 1);
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████████████";
					logo[4] += "    ████    ";
					logo[5] += "    ████    ";
					logo[6] += "    ████    ";
					logo[7] += "    ████    ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'u':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "████    ████";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'v':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████    ████";
					logo[4] += "████    ████";
					logo[5] += "████    ████";
					logo[6] += "  ████  ████";
					logo[7] += "     █████  ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'w':
					logo[0] += "               ";
					logo[1] += "               ";
					logo[2] += "               ";
					logo[3] += "███   ███   ███";
					logo[4] += "███   ███   ███";
					logo[5] += "███   ███   ███";
					logo[6] += "  ██  ████  ███";
					logo[7] += "    ████  ████ ";
					logo[8] += "               ";
					logo[9] += "███████████████";
					break;
				case 'x':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████    ████";
					logo[4] += "  ████ ████ ";
					logo[5] += "    ████    ";
					logo[6] += " ████ ████  ";
					logo[7] += "████    ████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'y':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████    ████";
					logo[4] += "  ████ ████ ";
					logo[5] += "    ████    ";
					logo[6] += "    ████    ";
					logo[7] += "    ████    ";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				case 'z':
					logo[0] += "            ";
					logo[1] += "            ";
					logo[2] += "            ";
					logo[3] += "████████████";
					logo[4] += "      ████  ";
					logo[5] += "    ████    ";
					logo[6] += "  ████      ";
					logo[7] += "████████████";
					logo[8] += "            ";
					logo[9] += "████████████";
					break;
				default:
					System.out.println("Unable to convert character '" + c + "'");
					break;
			}
		}
		
		// Italicize logo
		if(italic) {
			for(int i = 0; i < logo.length; i++) {
				// i = 0 -> 9
				for(int x = logo.length - (i + 1); x > 0; x--)
					// x = 10 - (i + 1)  
					logo[i] = " " + logo[i]; // line 0 gets 10 spaces, line 1 gets 9 spaces... line 9 gets 0 spaces
			}
		}
		
		// Compile logo into single text element
		StringBuilder logoText = new StringBuilder();
		for(int i = logo.length - height; i < logo.length; i++) {
			logoText.append(logo[i] + "\n");
		}
		
		return logoText.toString();
		
	}
	
}
